@@ -5,8 +5,8 @@ use warnings;
 use strict;
 use base qw(Net::Amazon::Property);
 
-__PACKAGE__->make_accessor($_) for qw(title publisher binding isbn 
-    dewey_decimal numpages edition ean);
+__PACKAGE__->make_accessor($_) for qw(publisher binding isbn 
+    dewey_decimal numpages edition ean publication_date);
 __PACKAGE__->make_array_accessor($_) for qw(authors);
 
 ##################################################
@@ -37,8 +37,6 @@ sub init_via_xmlref {
     $self->binding($ref->{Binding});
     $self->dewey_decimal($ref->{DeweyDecimalNumber});
     $self->numpages($ref->{NumberOfPages});
-    $self->title($ref->{Title});
-    $self->Title($ref->{Title});
     $self->publisher($ref->{Publisher});
     $self->isbn($ref->{ISBN});
     $self->edition($ref->{Edition});
@@ -50,7 +48,7 @@ sub init_via_xmlref {
     }
     $self->year($year);
 
-    $self->ReleaseDate($ref->{PublicationDate});
+    $self->publication_date($ref->{PublicationDate});
 }
 
 ##################################################
@@ -140,7 +138,19 @@ Returns the number of pages.
 
 =item dewey_decimal()
 
-Returns the Dewey decimal number.
+Returns the Dewey decimal number, this is for non-fiction only.
+
+=item publication_date()
+
+Returns the publication date.
+
+=item ReleaseDate()
+
+Returns the release date.
+
+For historical reasons, this method used to return the publication date. 
+However, as of version Net::Amazon 0.44 the release date is returned, and 
+a separate L</publication_date()> method is available. 
 
 =item new(xmlref => $xmlref)
 
